# ReinstatementsDueSummaryResponse

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**work_reference_number** | **str** |  | 
**permit_reference_number** | **str** |  | 
**organisation_name** | **str** |  | 
**street** | **str** |  | 
**town** | **str** |  | 
**area** | **str** |  | 
**work_stopped_date** | **datetime** |  | 
**registration_due_date** | **datetime** |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

